@@ -24,32 +24,19 @@
 #
 ###############################################################################
 
-from __future__ import absolute_import
-
+import asyncio
+from asyncio import iscoroutine
+from asyncio import Future
 from collections import deque
 
 import txaio
 txaio.use_asyncio()
 
 from autobahn.util import public
+from autobahn.asyncio.util import transport_channel_id, peer2str
 from autobahn.wamp import websocket
 from autobahn.websocket import protocol
-
-try:
-    import asyncio
-    from asyncio import iscoroutine
-    from asyncio import Future
-except ImportError:
-    # Trollius >= 0.3 was renamed
-    # noinspection PyUnresolvedReferences
-    import trollius as asyncio
-    from trollius import iscoroutine
-    from trollius import Future
-
-if hasattr(asyncio, 'ensure_future'):
-    ensure_future = asyncio.ensure_future
-else:  # Deprecated since Python 3.4.4
-    ensure_future = asyncio.async
+from autobahn.websocket.types import TransportDetails
 
 __all__ = (
     'WebSocketServerProtocol',
@@ -77,22 +64,20 @@ class WebSocketAdapterProtocol(asyncio.Protocol):
     Adapter class for asyncio-based WebSocket client and server protocols.
     """
 
+    peer = None
+    peer_transport = None
+
     def connection_made(self, transport):
         self.transport = transport
-
         self.receive_queue = deque()
         self._consume()
 
+        # the peer we are connected to
         try:
-            peer = transport.get_extra_info('peername')
-            try:
-                # FIXME: tcp4 vs tcp6
-                self.peer = u"tcp:%s:%d" % (peer[0], peer[1])
-            except:
-                # e.g. Unix Domain sockets don't have host/port
-                self.peer = u"unix:{0}".format(peer)
+            self.peer = peer2str(transport.get_extra_info('peername'))
         except:
-            self.peer = u"?"
+            self.peer = 'process:{}'.format(self.transport.pid)
+        self.peer_transport = 'websocket'
 
         self._connectionMade()
 
@@ -108,7 +93,7 @@ class WebSocketAdapterProtocol(asyncio.Protocol):
         self.waiter = Future(loop=self.factory.loop or txaio.config.loop)
 
         def process(_):
-            while len(self.receive_queue):
+            while self.receive_queue:
                 data = self.receive_queue.popleft()
                 if self.transport:
                     self._dataReceived(data)
@@ -121,75 +106,78 @@ class WebSocketAdapterProtocol(asyncio.Protocol):
         if not self.waiter.done():
             self.waiter.set_result(None)
 
-    # noinspection PyUnusedLocal
     def _closeConnection(self, abort=False):
-        self.transport.close()
+        if abort and hasattr(self.transport, 'abort'):
+            self.transport.abort()
+        else:
+            self.transport.close()
 
     def _onOpen(self):
         res = self.onOpen()
         if yields(res):
-            ensure_future(res)
+            asyncio.ensure_future(res)
 
     def _onMessageBegin(self, isBinary):
         res = self.onMessageBegin(isBinary)
         if yields(res):
-            ensure_future(res)
+            asyncio.ensure_future(res)
 
     def _onMessageFrameBegin(self, length):
         res = self.onMessageFrameBegin(length)
         if yields(res):
-            ensure_future(res)
+            asyncio.ensure_future(res)
 
     def _onMessageFrameData(self, payload):
         res = self.onMessageFrameData(payload)
         if yields(res):
-            ensure_future(res)
+            asyncio.ensure_future(res)
 
     def _onMessageFrameEnd(self):
         res = self.onMessageFrameEnd()
         if yields(res):
-            ensure_future(res)
+            asyncio.ensure_future(res)
 
     def _onMessageFrame(self, payload):
         res = self.onMessageFrame(payload)
         if yields(res):
-            ensure_future(res)
+            asyncio.ensure_future(res)
 
     def _onMessageEnd(self):
         res = self.onMessageEnd()
         if yields(res):
-            ensure_future(res)
+            asyncio.ensure_future(res)
 
     def _onMessage(self, payload, isBinary):
         res = self.onMessage(payload, isBinary)
         if yields(res):
-            ensure_future(res)
+            asyncio.ensure_future(res)
 
     def _onPing(self, payload):
         res = self.onPing(payload)
         if yields(res):
-            ensure_future(res)
+            asyncio.ensure_future(res)
 
     def _onPong(self, payload):
         res = self.onPong(payload)
         if yields(res):
-            ensure_future(res)
+            asyncio.ensure_future(res)
 
     def _onClose(self, wasClean, code, reason):
         res = self.onClose(wasClean, code, reason)
         if yields(res):
-            ensure_future(res)
-
-    def get_channel_id(self):
-        """
-        Implements :func:`autobahn.wamp.interfaces.ITransport.get_channel_id`
-        """
-        self.log.debug('FIXME: transport channel binding not implemented for asyncio (autobahn-python issue #729)')
-        return None
+            asyncio.ensure_future(res)
 
     def registerProducer(self, producer, streaming):
         raise Exception("not implemented")
 
+    def unregisterProducer(self):
+        # note that generic websocket/protocol.py code calls
+        # .unregisterProducer whenever we dropConnection -- that's
+        # correct behavior on Twisted so either we'd have to
+        # try/except there, or special-case Twisted, ..or just make
+        # this "not an error"
+        pass
+
 
 @public
 class WebSocketServerProtocol(WebSocketAdapterProtocol, protocol.WebSocketServerProtocol):
@@ -203,6 +191,12 @@ class WebSocketServerProtocol(WebSocketAdapterProtocol, protocol.WebSocketServer
 
     log = txaio.make_logger()
 
+    def get_channel_id(self, channel_id_type=None):
+        """
+        Implements :func:`autobahn.wamp.interfaces.ITransport.get_channel_id`
+        """
+        return transport_channel_id(self.transport, True, channel_id_type)
+
 
 @public
 class WebSocketClientProtocol(WebSocketAdapterProtocol, protocol.WebSocketClientProtocol):
@@ -219,11 +213,31 @@ class WebSocketClientProtocol(WebSocketAdapterProtocol, protocol.WebSocketClient
     def _onConnect(self, response):
         res = self.onConnect(response)
         if yields(res):
-            ensure_future(res)
+            asyncio.ensure_future(res)
 
     def startTLS(self):
         raise Exception("WSS over explicit proxies not implemented")
 
+    def get_channel_id(self, channel_id_type=None):
+        """
+        Implements :func:`autobahn.wamp.interfaces.ITransport.get_channel_id`
+        """
+        return transport_channel_id(self.transport, False, channel_id_type)
+
+    def _create_transport_details(self):
+        """
+        Internal helper.
+        Base class calls this to create a TransportDetails
+        """
+        is_secure = self.transport.get_extra_info('peercert', None) is not None
+        if is_secure:
+            secure_channel_id = {
+                'tls-unique': transport_channel_id(self.transport, False, 'tls-unique'),
+            }
+        else:
+            secure_channel_id = {}
+        return TransportDetails(peer=self.peer, is_secure=is_secure, secure_channel_id=secure_channel_id)
+
 
 class WebSocketAdapterFactory(object):
     """
