@@ -25,7 +25,7 @@
 ###############################################################################
 
 import abc
-import six
+from typing import Union
 
 from autobahn.util import public
 
@@ -36,13 +36,13 @@ __all__ = (
     'ITransport',
     'ITransportHandler',
     'ISession',
-    'IPayloadCodec'
+    'IPayloadCodec',
+    'ISigningKey'
 )
 
 
 @public
-@six.add_metaclass(abc.ABCMeta)
-class IObjectSerializer(object):
+class IObjectSerializer(abc.ABC):
     """
     Raw Python object serialization and deserialization. Object serializers are
     used by classes implementing WAMP serializers, that is instances of
@@ -85,8 +85,7 @@ class IObjectSerializer(object):
 
 
 @public
-@six.add_metaclass(abc.ABCMeta)
-class ISerializer(object):
+class ISerializer(abc.ABC):
     """
     WAMP message serialization and deserialization.
     """
@@ -137,8 +136,7 @@ class ISerializer(object):
 
 
 @public
-@six.add_metaclass(abc.ABCMeta)
-class IMessage(object):
+class IMessage(abc.ABC):
     """
     """
 
@@ -188,8 +186,7 @@ class IMessage(object):
 
 
 @public
-@six.add_metaclass(abc.ABCMeta)
-class ITransport(object):
+class ITransport(abc.ABC):
     """
     A WAMP transport is a bidirectional, full-duplex, reliable, ordered,
     message-based channel.
@@ -287,8 +284,7 @@ class ITransport(object):
 
 
 @public
-@six.add_metaclass(abc.ABCMeta)
-class ITransportHandler(object):
+class ITransportHandler(abc.ABC):
 
     @public
     @abc.abstractproperty
@@ -335,8 +331,7 @@ class ITransportHandler(object):
 
 
 @public
-@six.add_metaclass(abc.ABCMeta)
-class ISession(object):
+class ISession(abc.ABC):
     """
     Interface for WAMP sessions.
     """
@@ -404,6 +399,22 @@ class ISession(object):
         :type challenge: Instance of :class:`autobahn.wamp.types.Challenge`.
         """
 
+    @public
+    @abc.abstractmethod
+    def onWelcome(self, welcome_msg):
+        """
+        Callback fired after the peer has successfully authenticated. If
+        this returns anything other than None/False, the session is
+        aborted and the return value is used as an error message.
+
+        May return a Deferred/Future.
+
+        :param welcome_msg: The WELCOME message received from the server
+        :type challenge: Instance of :class:`autobahn.wamp.message.Welcome`.
+
+        :return: None, or an error message
+        """
+
     @public
     @abc.abstractmethod
     def onJoin(self, details):
@@ -537,7 +548,7 @@ class ISession(object):
         When the *Caller* and *Dealer* implementations support canceling of calls, the call may
         be canceled by canceling the returned Deferred/Future.
 
-        :param procedure: The URI of the remote procedure to be called, e.g. ``u"com.myapp.hello"``.
+        :param procedure: The URI of the remote procedure to be called, e.g. ``"com.myapp.hello"``.
         :type procedure: unicode
 
         :param args: Any positional arguments for the call.
@@ -552,7 +563,7 @@ class ISession(object):
 
     @public
     @abc.abstractmethod
-    def register(self, endpoint, procedure=None, options=None, prefix=None):
+    def register(self, endpoint, procedure=None, options=None, prefix=None, check_types=None):
         """
         Register a procedure for remote calling.
 
@@ -590,6 +601,15 @@ class ISession(object):
             'com.something.method_foo' would ultimately be registered.
         :type prefix: str
 
+        :param check_types: Enable automatic type checking against (Python 3.5+) type hints
+            specified on the ``endpoint`` callable. Types are checked at run-time on each
+            invocation of the ``endpoint`` callable. When a type mismatch occurs, the error
+            is forwarded to the callee code in ``onUserError`` override method of
+            :class:`autobahn.wamp.protocol.ApplicationSession`. An error
+            of type :class:`autobahn.wamp.exception.TypeCheckError` is also raised and
+            returned to the caller (via the router).
+        :type check_types: bool
+
         :returns: A registration or a list of registrations (or errors)
         :rtype: instance(s) of :tx:`twisted.internet.defer.Deferred` / :py:class:`asyncio.Future`
         """
@@ -618,7 +638,7 @@ class ISession(object):
         - If the publication fails the Deferred/Future will reject with an instance
           of :class:`autobahn.wamp.exception.ApplicationError`.
 
-        :param topic: The URI of the topic to publish to, e.g. ``u"com.myapp.mytopic1"``.
+        :param topic: The URI of the topic to publish to, e.g. ``"com.myapp.mytopic1"``.
         :type topic: unicode
 
         :param args: Arbitrary application payload for the event (positional arguments).
@@ -633,7 +653,7 @@ class ISession(object):
 
     @public
     @abc.abstractmethod
-    def subscribe(self, handler, topic=None, options=None):
+    def subscribe(self, handler, topic=None, options=None, check_types=None):
         """
         Subscribe to a topic for receiving events.
 
@@ -663,24 +683,77 @@ class ISession(object):
         :param options: Options for subscribing.
         :type options: An instance of :class:`autobahn.wamp.types.SubscribeOptions`.
 
+        :param check_types: Enable automatic type checking against (Python 3.5+) type hints
+            specified on the ``endpoint`` callable. Types are checked at run-time on each
+            invocation of the ``endpoint`` callable. When a type mismatch occurs, the error
+            is forwarded to the subscriber code in ``onUserError`` override method of
+            :class:`autobahn.wamp.protocol.ApplicationSession`.
+        :type check_types: bool
+
         :returns: A single Deferred/Future or a list of such objects
         :rtype: instance(s) of :tx:`twisted.internet.defer.Deferred` / :py:class:`asyncio.Future`
         """
 
 
 # experimental authentication API
-@six.add_metaclass(abc.ABCMeta)
-class IAuthenticator(object):
+class IAuthenticator(abc.ABC):
 
     @abc.abstractmethod
     def on_challenge(self, session, challenge):
         """
+        Formulate a challenge response for the given session and Challenge
+        instance. This is sent to the server in the AUTHENTICATE
+        message.
+        """
+
+    @abc.abstractmethod
+    def on_welcome(self, authextra):
+        """
+        This hook is called when the onWelcome/on_welcome hook is invoked
+        in the protocol, with the 'authextra' dict extracted from the
+        Welcome message. Usually this is used to verify the final
+        message from the server (e.g. for mutual authentication).
+
+        :return: None if the session is successful or an error-message
         """
 
 
 @public
-@six.add_metaclass(abc.ABCMeta)
-class IPayloadCodec(object):
+class ISigningKey(abc.ABC):
+
+    @abc.abstractmethod
+    def can_sign(self):
+        """
+        Check if the key can be used to sign.
+
+        :returns: `True`, iff the key can sign.
+        :rtype: bool
+        """
+
+    @abc.abstractmethod
+    def public_key(self, binary=False) -> Union[str, bytes]:
+        """
+        Returns the public key part of a signing key or the (public) verification key.
+
+        :param binary: If the return type should be binary instead of hex
+        :return: The public key in hex or byte encoding.
+        """
+
+    @abc.abstractmethod
+    def sign(self, data: bytes):
+        """
+        Sign the given data.
+
+        :param data: The data to be signed.
+        :type data: bytes
+
+        :returns: The signature.
+        :rtype: txaio.Future object that resolves to bytes
+        """
+
+
+@public
+class IPayloadCodec(abc.ABC):
     """
     WAMP payload codecs are used with WAMP payload transparency mode.
 
