@@ -36,9 +36,9 @@ class Component(ApplicationSession):
 
     async def onJoin(self, details):
 
-        procs = [u'com.mathservice.add2',
-                 u'com.mathservice.mul2',
-                 u'com.mathservice.div2']
+        procs = ['com.mathservice.add2',
+                 'com.mathservice.mul2',
+                 'com.mathservice.div2']
 
         try:
             for proc in procs:
@@ -54,8 +54,7 @@ class Component(ApplicationSession):
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
