@@ -24,7 +24,6 @@
 #
 ###############################################################################
 
-from __future__ import print_function
 from os import environ
 
 from twisted.internet.defer import inlineCallbacks
@@ -44,14 +43,13 @@ class Component(ApplicationSession):
         counter = 0
         while True:
             print('backend publishing com.myapp.topic1', counter)
-            self.publish(u'com.myapp.topic1', counter)
+            self.publish('com.myapp.topic1', counter)
             counter += 1
             yield sleep(1)
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
