@@ -46,23 +46,22 @@ class Component(ApplicationSession):
             print("square called from: {}".format(details.caller))
 
             if val < 0:
-                self.publish(u'com.myapp.square_on_nonpositive', val)
+                self.publish('com.myapp.square_on_nonpositive', val)
             elif val == 0:
                 if details.caller:
                     options = PublishOptions(exclude=[details.caller])
                 else:
                     options = None
-                self.publish(u'com.myapp.square_on_nonpositive', val, options=options)
+                self.publish('com.myapp.square_on_nonpositive', val, options=options)
             return val * val
 
-        yield self.register(square, u'com.myapp.square', RegisterOptions(details_arg='details'))
+        yield self.register(square, 'com.myapp.square', RegisterOptions(details_arg='details'))
 
         print("procedure registered")
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
