@@ -53,14 +53,13 @@ class Component(ApplicationSession):
                 yield sleep(1 * n)
             returnValue(n)
 
-        yield self.register(longop, u'com.myapp.longop', RegisterOptions(details_arg='details'))
+        yield self.register(longop, 'com.myapp.longop', RegisterOptions(details_arg='details'))
 
         print("procedures registered")
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
