@@ -44,21 +44,20 @@ class Component(ApplicationSession):
         def square(x):
             return x * x
 
-        yield self.register(square, u'com.math.square')
+        yield self.register(square, 'com.math.square')
 
         @inlineCallbacks
         def slowsquare(x, delay=1):
             yield sleep(delay)
             returnValue(x * x)
 
-        yield self.register(slowsquare, u'com.math.slowsquare')
+        yield self.register(slowsquare, 'com.math.slowsquare')
 
         print("procedures registered")
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
