@@ -46,11 +46,11 @@ class Component(ApplicationSession):
             print("{}: {} in {}".format(msg, res, duration))
 
         t1 = time.clock()
-        d1 = self.call(u'com.math.slowsquare', 3)
+        d1 = self.call('com.math.slowsquare', 3)
         d1.addCallback(got, t1, "Slow Square")
 
         t2 = time.clock()
-        d2 = self.call(u'com.math.square', 3)
+        d2 = self.call('com.math.square', 3)
         d2.addCallback(got, t2, "Quick Square")
 
         def done(_):
@@ -65,8 +65,7 @@ class Component(ApplicationSession):
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
