@@ -40,7 +40,7 @@ class Component(ApplicationSession):
     def onJoin(self, details):
         print("session attached")
         try:
-            now = yield self.call(u'com.timeservice.now')
+            now = yield self.call('com.timeservice.now')
         except Exception as e:
             print("Error: {}".format(e))
         else:
@@ -54,8 +54,7 @@ class Component(ApplicationSession):
 
 
 if __name__ == '__main__':
-    runner = ApplicationRunner(
-        environ.get("AUTOBAHN_DEMO_ROUTER", u"ws://127.0.0.1:8080/ws"),
-        u"crossbardemo",
-    )
+    url = environ.get("AUTOBAHN_DEMO_ROUTER", "ws://127.0.0.1:8080/ws")
+    realm = "crossbardemo"
+    runner = ApplicationRunner(url, realm)
     runner.run(Component)
